@@ -1,13 +1,12 @@
+"""Database tools.
+"""
 
-"""Database tools."""
-
-from __future__ import division, absolute_import, print_function
-
-import os
 import io
+import os
+
 import skytools
 
-__all__ = [
+__all__ = (
     "fq_name_parts", "fq_name", "get_table_oid", "get_table_pkeys",
     "get_table_columns", "exists_schema", "exists_table", "exists_type",
     "exists_sequence", "exists_temp_table", "exists_view",
@@ -15,27 +14,11 @@ __all__ = [
     "CopyPipe", "full_copy", "DBObject", "DBSchema", "DBTable", "DBFunction",
     "DBLanguage", "db_install", "installer_find_file", "installer_apply_file",
     "dbdict", "mk_insert_sql", "mk_update_sql", "mk_delete_sql",
-]
+)
+
 
 class dbdict(dict):
     """Wrapper on actual dict that allows accessing dict keys as attributes.
-
-    >>> row = dbdict(a=1, b=2)
-    >>> row.a, row.b, row['a'], row['b']
-    (1, 2, 1, 2)
-    >>> row.c = 3; row['c']
-    3
-    >>> del row.c; row.c
-    Traceback (most recent call last):
-        ...
-    AttributeError: c
-    >>> row['c']
-    Traceback (most recent call last):
-        ...
-    KeyError: 'c'
-    >>> row.merge({'q': 4}); row.q
-    4
-
     """
     # obj.foo access
     def __getattr__(self, k):
@@ -55,19 +38,13 @@ class dbdict(dict):
             if key not in self:
                 self[key] = other[key]
 
+
 #
 # Fully qualified table name
 #
 
 def fq_name_parts(tbl):
     """Return fully qualified name parts.
-
-    >>> fq_name_parts('tbl')
-    ['public', 'tbl']
-    >>> fq_name_parts('foo.tbl')
-    ['foo', 'tbl']
-    >>> fq_name_parts('foo.tbl.baz')
-    ['foo', 'tbl.baz']
     """
 
     tmp = tbl.split('.', 1)
@@ -75,21 +52,17 @@ def fq_name_parts(tbl):
         return ['public', tbl]
     return tmp
 
+
 def fq_name(tbl):
     """Return fully qualified name.
-
-    >>> fq_name('tbl')
-    'public.tbl'
-    >>> fq_name('foo.tbl')
-    'foo.tbl'
-    >>> fq_name('foo.tbl.baz')
-    'foo.tbl.baz'
     """
     return '.'.join(fq_name_parts(tbl))
 
+
 #
 # info about table
 #
+
 def get_table_oid(curs, table_name):
     """Find Postgres OID for table."""
     schema, name = fq_name_parts(table_name)
@@ -99,9 +72,10 @@ def get_table_oid(curs, table_name):
     curs.execute(q, [schema, name])
     res = curs.fetchall()
     if len(res) == 0:
-        raise Exception('Table not found: '+table_name)
+        raise Exception('Table not found: ' + table_name)
     return res[0][0]
 
+
 def get_table_pkeys(curs, tbl):
     """Return list of pkey column names."""
     oid = get_table_oid(curs, tbl)
@@ -112,6 +86,7 @@ def get_table_pkeys(curs, tbl):
     curs.execute(q, [oid])
     return [row[0] for row in curs.fetchall()]
 
+
 def get_table_columns(curs, tbl):
     """Return list of column names for table."""
     oid = get_table_oid(curs, tbl)
@@ -122,9 +97,11 @@ def get_table_columns(curs, tbl):
     curs.execute(q, [oid])
     return [row[0] for row in curs.fetchall()]
 
+
 #
 # exist checks
 #
+
 def exists_schema(curs, schema):
     """Does schema exists?"""
     q = "select count(1) from pg_namespace where nspname = %s"
@@ -132,6 +109,7 @@ def exists_schema(curs, schema):
     res = curs.fetchone()
     return res[0]
 
+
 def exists_table(curs, table_name):
     """Does table exists?"""
     schema, name = fq_name_parts(table_name)
@@ -142,6 +120,7 @@ def exists_table(curs, table_name):
     res = curs.fetchone()
     return res[0]
 
+
 def exists_sequence(curs, seq_name):
     """Does sequence exists?"""
     schema, name = fq_name_parts(seq_name)
@@ -152,6 +131,7 @@ def exists_sequence(curs, seq_name):
     res = curs.fetchone()
     return res[0]
 
+
 def exists_view(curs, view_name):
     """Does view exists?"""
     schema, name = fq_name_parts(view_name)
@@ -162,6 +142,7 @@ def exists_view(curs, view_name):
     res = curs.fetchone()
     return res[0]
 
+
 def exists_type(curs, type_name):
     """Does type exists?"""
     schema, name = fq_name_parts(type_name)
@@ -172,6 +153,7 @@ def exists_type(curs, type_name):
     res = curs.fetchone()
     return res[0]
 
+
 def exists_function(curs, function_name, nargs):
     """Does function exists?"""
     # this does not check arg types, so may match several functions
@@ -189,6 +171,7 @@ def exists_function(curs, function_name, nargs):
 
     return res[0]
 
+
 def exists_language(curs, lang_name):
     """Does PL exists?"""
     q = """select count(1) from pg_language
@@ -197,6 +180,7 @@ def exists_language(curs, lang_name):
     res = curs.fetchone()
     return res[0]
 
+
 def exists_temp_table(curs, tbl):
     """Does temp table exists?"""
     # correct way, works only on 8.2
@@ -205,28 +189,13 @@ def exists_temp_table(curs, tbl):
     tmp = curs.fetchall()
     return len(tmp) > 0
 
+
 #
 # Support for PostgreSQL snapshot
 #
 
-class Snapshot(object):
+class Snapshot:
     """Represents a PostgreSQL snapshot.
-
-    Example:
-    >>> sn = Snapshot('11:20:11,12,15')
-    >>> sn.contains(9)
-    True
-    >>> sn.contains(11)
-    False
-    >>> sn.contains(17)
-    True
-    >>> sn.contains(20)
-    False
-    >>> Snapshot(':')
-    Traceback (most recent call last):
-        ...
-    ValueError: Unknown format for snapshot
-
     """
 
     def __init__(self, str_val):
@@ -256,6 +225,7 @@ class Snapshot(object):
             return False
         return True
 
+
 #
 # Copy helpers
 #
@@ -267,6 +237,7 @@ def _gen_dict_copy(tbl, row, fields, qfields):
         tmp.append(skytools.quote_copy(v))
     return "\t".join(tmp)
 
+
 def _gen_dict_insert(tbl, row, fields, qfields):
     tmp = []
     for f in fields:
@@ -275,6 +246,7 @@ def _gen_dict_insert(tbl, row, fields, qfields):
     fmt = "insert into %s (%s) values (%s);"
     return fmt % (tbl, ",".join(qfields), ",".join(tmp))
 
+
 def _gen_list_copy(tbl, row, fields, qfields):
     tmp = []
     for i in range(len(fields)):
@@ -285,6 +257,7 @@ def _gen_list_copy(tbl, row, fields, qfields):
         tmp.append(skytools.quote_copy(v))
     return "\t".join(tmp)
 
+
 def _gen_list_insert(tbl, row, fields, qfields):
     tmp = []
     for i in range(len(fields)):
@@ -296,47 +269,19 @@ def _gen_list_insert(tbl, row, fields, qfields):
     fmt = "insert into %s (%s) values (%s);"
     return fmt % (tbl, ",".join(qfields), ",".join(tmp))
 
+
 def magic_insert(curs, tablename, data, fields=None, use_insert=False, quoted_table=False):
     r"""Copy/insert a list of dict/list data to database.
 
     If curs is None, then the copy or insert statements are returned
     as string.  For list of dict the field list is optional, as its
     possible to guess them from dict keys.
-
-    Example:
-    >>> magic_insert(None, 'tbl', [[1, '1'], [2, '2']], ['col1', 'col2'])
-    'COPY public.tbl (col1,col2) FROM STDIN;\n1\t1\n2\t2\n\\.\n'
-    >>> magic_insert(None, 'tbl', [[1, '1'], [2, '2']], ['col1', 'col2'], use_insert=True)
-    "insert into public.tbl (col1,col2) values ('1','1');\ninsert into public.tbl (col1,col2) values ('2','2');\n"
-    >>> magic_insert(None, 'tbl', [], ['col1', 'col2'])
-    >>> magic_insert(None, 'tbl."1"', [[1, '1'], [2, '2']], ['col1', 'col2'], quoted_table=True)
-    'COPY tbl."1" (col1,col2) FROM STDIN;\n1\t1\n2\t2\n\\.\n'
-    >>> magic_insert(None, 'tbl."1"', [[1, '1'], [2, '2']])
-    Traceback (most recent call last):
-        ...
-    Exception: Non-dict data needs field list
-    >>> magic_insert(None, 'a.tbl', [{'a':1}, {'a':2}])
-    'COPY a.tbl (a) FROM STDIN;\n1\n2\n\\.\n'
-    >>> magic_insert(None, 'a.tbl', [{'a':1}, {'a':2}], use_insert=True)
-    "insert into a.tbl (a) values ('1');\ninsert into a.tbl (a) values ('2');\n"
-
-    More fields than data:
-
-    >>> magic_insert(None, 'tbl', [[1, 'a']], ['col1', 'col2', 'col3'])
-    'COPY public.tbl (col1,col2,col3) FROM STDIN;\n1\ta\t\\N\n\\.\n'
-    >>> magic_insert(None, 'tbl', [[1, 'a']], ['col1', 'col2', 'col3'], use_insert=True)
-    "insert into public.tbl (col1,col2,col3) values ('1','a',null);\n"
-    >>> magic_insert(None, 'tbl', [{'a':1}, {'b':2}], ['a', 'b'], use_insert=False)
-    'COPY public.tbl (a,b) FROM STDIN;\n1\t\\N\n\\N\t2\n\\.\n'
-    >>> magic_insert(None, 'tbl', [{'a':1}, {'b':2}], ['a', 'b'], use_insert=True)
-    "insert into public.tbl (a,b) values ('1',null);\ninsert into public.tbl (a,b) values (null,'2');\n"
-
     """
     if len(data) == 0:
         return None
 
     if fields is not None:
-        fields = list(fields) # get rid of iterator
+        fields = list(fields)  # get rid of iterator
 
     # decide how to process
     if hasattr(data[0], 'keys'):
@@ -386,6 +331,7 @@ def magic_insert(curs, tablename, data, fields=None, use_insert=False, quoted_ta
         curs.copy_from(buf, hdr)
     return None
 
+
 #
 # Full COPY of table from one db to another
 #
@@ -394,7 +340,7 @@ class CopyPipe(io.TextIOBase):
     """Splits one big COPY to chunks.
     """
 
-    def __init__(self, dstcurs, tablename=None, limit=512*1024, sql_from=None):
+    def __init__(self, dstcurs, tablename=None, limit=512 * 1024, sql_from=None):
         super(CopyPipe, self).__init__()
         self.tablename = tablename
         self.sql_from = sql_from
@@ -418,7 +364,7 @@ class CopyPipe(io.TextIOBase):
         if self.write_hook:
             data = self.write_hook(self, data)
 
-        self.total_bytes += len(data) # it's chars now...
+        self.total_bytes += len(data)  # it's chars now...
         self.total_rows += 1
 
         self.buf.write(data)
@@ -445,8 +391,8 @@ class CopyPipe(io.TextIOBase):
 
 
 def full_copy(tablename, src_curs, dst_curs, column_list=(), condition=None,
-        dst_tablename=None, dst_column_list=None,
-        write_hook=None, flush_hook=None):
+              dst_tablename=None, dst_column_list=None,
+              write_hook=None, flush_hook=None):
     """COPY table from one db to another."""
 
     # default dst table and dst columns to source ones
@@ -492,7 +438,7 @@ def full_copy(tablename, src_curs, dst_curs, column_list=(), condition=None,
 # SQL installer
 #
 
-class DBObject(object):
+class DBObject:
     """Base class for installable DB objects."""
     name = None
     sql = None
@@ -513,7 +459,8 @@ class DBObject(object):
             fn = self.find_file()
             if log:
                 log.info("  Reading from %s" % fn)
-            sql = open(fn, "r").read()
+            with open(fn, "r") as f:
+                sql = f.read()
         else:
             raise Exception('object not defined')
         for stmt in skytools.parse_statements(sql):
@@ -524,18 +471,21 @@ class DBObject(object):
         """Find install script file."""
         return installer_find_file(self.sql_file)
 
+
 class DBSchema(DBObject):
     """Handles db schema."""
     def exists(self, curs):
         """Does schema exists."""
         return exists_schema(curs, self.name)
 
+
 class DBTable(DBObject):
     """Handles db table."""
     def exists(self, curs):
         """Does table exists."""
         return exists_table(curs, self.name)
 
+
 class DBFunction(DBObject):
     """Handles db function."""
     def __init__(self, name, nargs, sql=None, sql_file=None):
@@ -546,6 +496,7 @@ class DBFunction(DBObject):
         """Does function exists."""
         return exists_function(curs, self.name, self.nargs)
 
+
 class DBLanguage(DBObject):
     """Handles db language."""
     def __init__(self, name):
@@ -555,6 +506,7 @@ class DBLanguage(DBObject):
         """Does PL exists."""
         return exists_language(curs, self.name)
 
+
 def db_install(curs, obj_list, log=None):
     """Installs list of objects into db."""
     for obj in obj_list:
@@ -564,6 +516,7 @@ def db_install(curs, obj_list, log=None):
             if log:
                 log.info('%s is installed' % obj.name)
 
+
 def installer_find_file(filename):
     """Find SQL script from pre-defined paths."""
     full_fn = None
@@ -580,13 +533,15 @@ def installer_find_file(filename):
                 break
 
     if not full_fn:
-        raise Exception('File not found: '+filename)
+        raise Exception('File not found: ' + filename)
     return full_fn
 
+
 def installer_apply_file(db, filename, log):
     """Find SQL file and apply it to db, statement-by-statement."""
     fn = installer_find_file(filename)
-    sql = open(fn, "r").read()
+    with open(fn, "r") as f:
+        sql = f.read()
     if log:
         log.info("applying %s" % fn)
     curs = db.cursor()
@@ -594,22 +549,14 @@ def installer_apply_file(db, filename, log):
         #log.debug(repr(stmt))
         curs.execute(stmt)
 
+
 #
 # Generate INSERT/UPDATE/DELETE statement
 #
 
 def mk_insert_sql(row, tbl, pkey_list=None, field_map=None):
     """Generate INSERT statement from dict data.
-
-    >>> from collections import OrderedDict
-    >>> row = OrderedDict([('id',1), ('data', None)])
-    >>> mk_insert_sql(row, 'tbl')
-    "insert into public.tbl (id, data) values ('1', null);"
-    >>> mk_insert_sql(row, 'tbl', ['x'], OrderedDict([('id', 'id_'), ('data', 'data_')]))
-    "insert into public.tbl (id_, data_) values ('1', null);"
-
     """
-
     col_list = []
     val_list = []
     if field_map:
@@ -623,23 +570,12 @@ def mk_insert_sql(row, tbl, pkey_list=None, field_map=None):
     col_str = ", ".join(col_list)
     val_str = ", ".join(val_list)
     return "insert into %s (%s) values (%s);" % (
-                    skytools.quote_fqident(tbl), col_str, val_str)
+        skytools.quote_fqident(tbl), col_str, val_str)
+
 
 def mk_update_sql(row, tbl, pkey_list, field_map=None):
-    r"""Generate UPDATE statement from dict data.
-
-    >>> mk_update_sql({'id': 0, 'id2': '2', 'data': 'str\\'}, 'Table', ['id', 'id2'])
-    'update only public."Table" set data = E\'str\\\\\' where id = \'0\' and id2 = \'2\';'
-    >>> mk_update_sql({'id': 0, 'id2': '2', 'data': 'str\\'}, 'Table', ['id', 'id2'],
-    ...     {'id': '_id', 'id2': '_id2', 'data': '_data'})
-    'update only public."Table" set _data = E\'str\\\\\' where _id = \'0\' and _id2 = \'2\';'
-    >>> mk_update_sql({'id': 0, 'id2': '2', 'data': 'str\\'}, 'Table', [])
-    Traceback (most recent call last):
-        ...
-    Exception: update needs pkeys
-
+    """Generate UPDATE statement from dict data.
     """
-
     if len(pkey_list) < 1:
         raise Exception("update needs pkeys")
     set_list = []
@@ -665,22 +601,12 @@ def mk_update_sql(row, tbl, pkey_list, field_map=None):
                 val = skytools.quote_literal(val)
                 set_list.append("%s = %s" % (col, val))
     return "update only %s set %s where %s;" % (skytools.quote_fqident(tbl),
-            ", ".join(set_list), " and ".join(whe_list))
+                                                ", ".join(set_list), " and ".join(whe_list))
+
 
 def mk_delete_sql(row, tbl, pkey_list, field_map=None):
     """Generate DELETE statement from dict data.
-
-    >>> mk_delete_sql({'a': 1, 'b':2, 'c':3}, 'tablename', ['a','b'])
-    "delete from only public.tablename where a = '1' and b = '2';"
-    >>> mk_delete_sql({'a': 1, 'b':2, 'c':3}, 'tablename', ['a','b'], {'a': 'aa', 'b':'bb'})
-    "delete from only public.tablename where aa = '1' and bb = '2';"
-    >>> mk_delete_sql({'a': 1, 'b':2, 'c':3}, 'tablename', [])
-    Traceback (most recent call last):
-        ...
-    Exception: delete needs pkeys
-
     """
-
     if len(pkey_list) < 1:
         raise Exception("delete needs pkeys")
     whe_list = []
